<?php

namespace Drupal\glint;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Provides the GlintEntityHelper class.
 */
final class GlintEntityHelper implements GlintEntityHelperInterface {

  /**
   * The main Glint service.
   *
   * @var \Drupal\glint\GlintInterface
   */
  private GlintInterface $glint;

  /**
   * The entity attached to this helper.
   *
   * @var \Drupal\Core\Entity\ContentEntityInterface
   */
  public ContentEntityInterface $entity;

  /**
   * Constructs a GlintEntityHelper object.
   *
   * @param \Drupal\glint\Glint $glint
   *   The Glint service.
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity attached to this helper.
   */
  public function __construct(Glint $glint, ContentEntityInterface $entity) {
    $this->glint = $glint;
    $this->entity = $entity;
  }

  /**
   * {@inheritDoc}
   */
  public function title() : string {
    return $this->label();
  }

  /**
   * {@inheritDoc}
   */
  public function label() : string {
    return $this->entity->label();
  }

  /**
   * {@inheritDoc}
   */
  public function get(string $fieldName) : mixed {
    return $this->glint->get($fieldName, $this->entity);
  }

  /**
   * {@inheritDoc}
   */
  public function all() : array {
    $data = [];
    $fields = $this->entity->getFields();
    foreach (array_keys($fields) as $fieldName) {
      if (str_starts_with($fieldName, 'field_') || $fieldName === 'body') {
        $data[$fieldName] = $this->get($fieldName);
      }
    }
    return $data;
  }

  /**
   * {@inheritDoc}
   */
  public function getRaw(string $fieldName) : mixed {
    return $this->entity->get($fieldName)->getValue();
  }

  /**
   * {@inheritDoc}
   */
  public function allRaw() : array {
    return array_map(function ($itemList) {
      return $itemList->getValue();
    }, $this->entity->getFields());
  }

}
